// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'package:netease_common/netease_common.dart';
import 'package:netease_roomkit_interface/netease_roomkit_interface.dart';
import 'package:netease_roomkit_interface/src/pigeon.dart';

class MethodChannelChatController extends RoomChatControllerPlatform {
  final _api = RoomChatControllerApi();

  @override
  Future<VoidResult> joinChatroom(String roomUuid) {
    return _api
        .joinChatroom(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> leaveChatroom(String roomUuid) {
    return _api
        .leaveChatroom(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> sendBroadcastTextMessage(String roomUuid, String message) {
    return _api
        .sendBroadcastTextMessage(roomUuid, message)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> sendDirectTextMessage(
      String roomUuid, String userUuid, String message) {
    return _api
        .sendDirectTextMessage(roomUuid, userUuid, message)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> sendGroupTextMessage(
      String roomUuid, List<String> userUuids, String message) {
    return _api
        .sendGroupTextMessage(roomUuid, userUuids, message)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<NEResult<List<NEChatroomMember>>> fetchChatRoomMembers(
      String roomUuid, NEChatroomMemberQueryType queryType, int limit) {
    return _api
        .fetchChatRoomMembers(roomUuid, queryType.index, limit)
        .then((value) {
      List<NEChatroomMember> neChatRoomMembers = [];
      for (var element in value.chatRoomMembers) {
        neChatRoomMembers.add(
            NEChatroomMember(nick: element?.nick, avatar: element?.avatar));
      }
      return NEResult(
          code: value.code, msg: value.msg, data: neChatRoomMembers);
    });
  }

  @override
  Future<VoidResult> sendImageMessage(
    String roomUuid,
    String messageUuid,
    String imagePath,
    List<String>? userUuids,
  ) {
    return _api
        .sendImageMessage(roomUuid, messageUuid, imagePath, userUuids ?? [])
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> sendFileMessage(
    String roomUuid,
    String messageUuid,
    String filePath,
    List<String>? userUuids,
  ) {
    return _api
        .sendFileMessage(roomUuid, messageUuid, filePath, userUuids ?? [])
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> downloadAttachment(
    String roomUuid,
    String messageUuid,
  ) {
    return _api
        .downloadAttachment(roomUuid, messageUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> cancelDownloadAttachment(
    String roomUuid,
    String messageUuid,
  ) {
    return _api
        .cancelDownloadAttachment(roomUuid, messageUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }
}
