// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'package:netease_common/netease_common.dart';
import 'package:netease_roomkit_interface/src/pigeon.dart';
import 'package:netease_roomkit_interface/src/platform_interface/room_service_platform.dart';
import 'package:netease_roomkit_interface/src/types/room_service_models.dart';

class MethodChannelRoomService extends RoomServicePlatform {
  final _api = RoomServiceApi();

  @override
  Future<VoidResult> createRoom(params, options) {
    SeatInitParams? seatInitParams;
    if (params.seatInitParams != null) {
      seatInitParams = SeatInitParams(
          seatCount: params.seatInitParams!.seatCount,
          seatRequestApprovalMode:
              params.seatInitParams!.seatRequestApprovalMode,
          seatInvitationConfirmMode:
              params.seatInitParams!.seatInvitationConfirmMode);
    }
    return _api
        .createRoom(
          CreateRoomParams(
            roomUuid: params.roomUuid,
            roomName: params.roomName,
            password: params.password,
            templateId: params.templateId,
            seatInitParams: seatInitParams,
            initialProperties: params.initialRoomProperties,
          ),
          CreateRoomOptions(
            enableRecord: options.enableRecord,
            enableLive: options.enableLive,
            enableRtc: options.enableRtc,
            enableChatroom: options.enableChatroom,
            enableWhiteboard: options.enableWhiteboard,
            // enableSip: options.enableSip,
          ),
        )
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<NEResult<RoomSnapshot>> joinRoom(
      NEJoinRoomParams params, NEJoinRoomOptions options) {
    return _api
        .joinRoom(
      JoinRoomParams(
        roomUuid: params.roomUuid,
        userName: params.userName,
        avatar: params.avatar,
        password: params.password,
        role: params.role,
        crossAppAuthorization: params.crossAppAuthorization != null
            ? CrossAppAuthorization(
                appKey: params.crossAppAuthorization!.appKey,
                user: params.crossAppAuthorization!.user,
                token: params.crossAppAuthorization!.token,
              )
            : null,
        initialProperties: params.initialMyProperties,
      ),
      JoinRoomOptions(
        enableMyAudioDeviceOnJoinRtc: options.enableMyAudioDeviceOnJoinRtc,
      ),
    )
        .then((value) {
      return NEResult(code: value.code, msg: value.msg, data: value.snapshot);
    });
  }

  @override
  Future<VoidResult> previewRoom(
      NEPreviewRoomParams params, NEPreviewRoomOptions options) {
    return _api
        .previewRoom(PreviewRoomParams(), PreviewRoomOptions())
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }
}
